#!/usr/bin/env sh

#  'make_jet.sh', GPL


# set the script version here
jet_version="`cat VERSION`"

jet_script='jet.sh.in'
jet_configuration='configuration/configuration.jet'

jet_packer='xz'
jet_packer_args='-6'

# this is broken, don't use
# (seems to be a problem with line numbers)
#jet_packer='gzip'
#jet_packer_args='-9'


mjbookmaker_version='mjbookmaker-5.0.8'
mjbookmaker_dir='mjbookmaker'
mjbookmaker_binary='mjbookmaker.exe'
mjbookmaker_archive='mjbookmaker-jet.tar.xz'

mjsoft_url='http://www.mjsoft.info/eng/mjbook.php'

package="jet-${jet_version}+bin.sh"
package_link='jet'
package_destination='/usr/local/bin'

test_file="TheCulture.txt.xz"
test_book='TheCulture.jar'

verbose='echo' # ':'


_make_clean () {

	rm -f "$package" "$package_link" "$test_book" "jet.log"
	cd "$mjbookmaker_dir"
	rm -f "book.png" "splash.empty.png" "splash.example.png" "configuration"

	$verbose 'Cleanup complete.'
}

_set_archive_lines () {

	archive_lines=`wc -l "$mjbookmaker_archive" | cut -f1 -d' '`
	a_lines=$(echo $archive_lines+1 | bc)
	
	#$verbose "archive lines: $a_lines"
	sed -i "s/ARCHIVE_LINES/$a_lines/" "$package"
}

_test_package () {

	local command="./$package_link"

	$verbose
	$verbose "Testing './$package $test_file'..."
	$command $test_file
	ls -l --color=auto
}

_install_package () {

	$verbose "installing '$package'..."
	cp -iv "$package" "$package_link" "$package_destination"

	$verbose "Run '$ jet --help' to get started."
}


case $1 in

	*-h*)	echo "Usage: $0 [-test|-install|-clean]"
		exit 0
		;;

	*-t*)	_test_package
		exit 0
		;;

	*-i*)	_install_package
		exit 0
		;;

	*-c*)	_make_clean
		exit 0
		;;
esac

$verbose
$0 -c

$verbose "Generating 'jet-$jet_version'..."
$verbose

if [ ! -f "$mjbookmaker_dir/$mjbookmaker_binary" ]; then

	echo "Error: '$mjbookmaker_dir/$mjbookmaker_binary' not found."
	echo "get it here: <$mjsoft_url>"
	echo
	exit 1
fi

cp -v "$jet_configuration" "$mjbookmaker_dir/configuration"
cp -v images/* "$mjbookmaker_dir"

tar cvf - "$mjbookmaker_dir" | $jet_packer $jet_packer_args > "$mjbookmaker_archive"

cat "$jet_script" | sed -e "s/jet_version='*.*.*'/jet_version=$jet_version/" > "$package"
cat "$mjbookmaker_archive" >> "$package"

_set_archive_lines

rm "$mjbookmaker_archive"

chmod 755 "$package"
[ -h "$package_link" ] || ln -s "$package" "$package_link"


_test_package

